package session;

import entité.Photo;
import java.awt.image.*;
import java.io.*;
import java.util.*;
import javax.ejb.*;
import javax.imageio.ImageIO;
import javax.jws.*;
import javax.persistence.*;

@WebService
@Stateless
public class Archiver  {
    private final String répertoire = "E:/Archivage/";
    @PersistenceContext
    EntityManager persistance;

    public void stocker(String nom, List<Byte> listeOctets) throws IOException {
        byte[] octets = new byte[listeOctets.size()];
        for (int i=0; i<listeOctets.size(); i++) octets[i] = listeOctets.get(i);
        stocker(nom, octets);
    }

    public List<Byte> restituer(String nom) throws IOException {
        List<Byte> octets = new ArrayList<Byte>();
        for (byte octet : récupérer(nom)) octets.add(octet);
        return octets;
    }

    private void stocker(String nom, byte[] octets) throws IOException  {
        File fichier = new File(répertoire+nom);
        if (fichier.exists()) return;
        FileOutputStream photo = new FileOutputStream(fichier);
        photo.write(octets);
        photo.close();
        enregistrer(nom);
    }

    @Asynchronous
    private void enregistrer(String nom) throws IOException {
        File fichier = new File(répertoire+nom);
        BufferedImage image = ImageIO.read(fichier);
        Photo photo = new Photo(nom, fichier.length());
        photo.setDimensions(image);
        persistance.persist(photo);
    }

    private byte[] récupérer(String nom) throws IOException {
        File fichier = new File(répertoire+nom);
        if (!fichier.exists()) return null;
        FileInputStream photo = new FileInputStream(fichier);
        byte[] octets = new byte[(int)fichier.length()];
        photo.read(octets);
        photo.close();
        return octets;
    }

    public List<Photo> getListe() { return persistance.createNamedQuery("toutes").getResultList(); }

    public Photo getPhoto(String nom) {  return persistance.find(Photo.class, nom);   }

    public void supprimer(String nom) {
        new File(répertoire+nom).delete();
        Photo photo = getPhoto(nom);
        persistance.remove(photo);
    }
}
